Documentation — fedsim 0.1 documentation

# Documentation

## Subpackages

- fedsim.data_manager package
  - Submodules
  - fedsim.data_manager.basic_data_manager module
  - fedsim.data_manager.data_manager module
  - fedsim.data_manager.utils module
  - Module contents
- fedsim.datasets package
  - Module contents
- fedsim.fl package
  - Subpackages
    - fedsim.fl.algorithms package
      - Submodules
      - fedsim.fl.algorithms.adabest module
      - fedsim.fl.algorithms.fedavg module
      - fedsim.fl.algorithms.fedavgm module
      - fedsim.fl.algorithms.feddyn module
      - fedsim.fl.algorithms.fednova module
      - fedsim.fl.algorithms.fedprox module
      - Module contents
    - fedsim.fl.mtl_algorithms package
      - Module contents
  - Submodules
  - fedsim.fl.aggregators module
  - fedsim.fl.evaluation module
  - fedsim.fl.fl_algorithm module
  - fedsim.fl.utils module
  - Module contents
- fedsim.models package
  - Submodules
  - fedsim.models.mcmahan_nets module
  - Module contents

## Submodules

## fedsim.utils module

fedsim.utils.add_dict_to_dict(new_dict, currecnt_dict=None, scale=1)

fedsim.utils.add_in_dict(key, additive, currecnt_dict=None, scale=1)

fedsim.utils.append_dict_to_dict(new_dict, currecnt_dict=None)

fedsim.utils.apply_on_dict(dict_obj, fn, return_as_dict=False, *args, **kwargs)

fedsim.utils.get_from_module(module_name, submodule_name, class_name)

fedsim.utils.reduce_dict(to_reduct, reduction_fn=<function <lambda>>)

fedsim.utils.search_in_submodules(module_name, object_name)

fedsim.utils.set_seed(seed, use_cuda) → None

fedsim.utils.verify_dict(dict_obj)

## Module contents

a simple Federated Learning simulator!